==> react-molecule-select-1.13.0.tgz: package/lib/components/SingleSelection.js <==
import React, { Fragment } from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import withSelectUI from '../hoc/withSelectUI';
var MoleculeInputSelect = withSelectUI(AtomInput);

var MoleculeSelectSingleSelection = function MoleculeSelectSingleSelection(props) {
  /* eslint-disable react/prop-types */
  var _props$value = props.value,
      value = _props$value === void 0 ? '' : _props$value,
      children = props.children,
      isOpen = props.isOpen,
      onToggle = props.onToggle,
      onChange = props.onChange,
      iconArrowDown = props.iconArrowDown,
      refMoleculeSelect = props.refMoleculeSelect,
      size = props.size,
      placeholder = props.placeholder,
      id = props.id,
      disabled = props.disabled,
      _props$optionsData = props.optionsData,
      optionsData = _props$optionsData === void 0 ? {} : _props$optionsData;

  var handleSelection = function handleSelection(ev, _ref) {
    var value = _ref.value;
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeSelect.current.focus();
  };

  return React.createElement(Fragment, null, React.createElement(MoleculeInputSelect, {
    disabled: disabled,
    id: id,
    isOpen: isOpen,
    value: optionsData[value] || '',
    onClick: onToggle,
    iconArrowDown: iconArrowDown,
    placeholder: placeholder,
    autoComplete: "off",
    readOnly: true
  }), React.createElement(MoleculeDropdownList, {
    size: size,
    visible: isOpen,
    onSelect: handleSelection,
    value: value
  }, children));
};

MoleculeSelectSingleSelection.displayName = 'MoleculeSelectSingleSelection';
MoleculeSelectSingleSelection.defaultProps = {
  value: ''
};
export default MoleculeSelectSingleSelection;

==> react-molecule-select-1.17.0.tgz: package/lib/components/SingleSelection.js <==
import React from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import withSelectUI from '../hoc/withSelectUI';
var MoleculeInputSelect = withSelectUI(AtomInput);

var MoleculeSelectSingleSelection = function MoleculeSelectSingleSelection(props) {
  /* eslint-disable react/prop-types */
  var _props$value = props.value,
      value = _props$value === void 0 ? '' : _props$value,
      children = props.children,
      isOpen = props.isOpen,
      onToggle = props.onToggle,
      onChange = props.onChange,
      iconArrowDown = props.iconArrowDown,
      refMoleculeSelect = props.refMoleculeSelect,
      size = props.size,
      placeholder = props.placeholder,
      id = props.id,
      disabled = props.disabled,
      _props$optionsData = props.optionsData,
      optionsData = _props$optionsData === void 0 ? {} : _props$optionsData;

  var handleSelection = function handleSelection(ev, _ref) {
    var value = _ref.value;
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeSelect.current.focus();
  };

  return React.createElement(React.Fragment, null, React.createElement(MoleculeInputSelect, {
    disabled: disabled,
    id: id,
    isOpen: isOpen,
    value: optionsData[value] || '',
    onClick: onToggle,
    iconArrowDown: iconArrowDown,
    placeholder: placeholder,
    autoComplete: "off",
    readOnly: true
  }), React.createElement(MoleculeDropdownList, {
    size: size,
    visible: isOpen,
    onSelect: handleSelection,
    value: value
  }, children));
};

MoleculeSelectSingleSelection.displayName = 'MoleculeSelectSingleSelection';
MoleculeSelectSingleSelection.defaultProps = {
  value: ''
};
export default MoleculeSelectSingleSelection;
